extends Node

@export var circle_scene: PackedScene;
@export var cross_scene: PackedScene;

## The size of the grid, in pixels.
var grid_size: int
## The size of each cell, in pixels.
var cell_size: int


# Called when the node enters the scene tree for the first time.
func _ready() -> void:
	grid_size = $Grid.texture.get_width()
	cell_size = grid_size / 3
	$State.setup()


# Called every frame. 'delta' is the elapsed time since the previous frame.
func _process(delta: float) -> void:
	pass

## Called every input. 'event' describes the input.
func _input(event: InputEvent) -> void:
	if $State.game_end():
		return
	if event is InputEventMouseButton:
		var do_step = event.button_index == MOUSE_BUTTON_LEFT and \
			event.pressed and \
			event.position.x < grid_size
		if do_step:
			var ij = Vector2i(event.position / cell_size)
			$State.step(ij.y, ij.x)
			update_view(ij)
			print($State.state_to_string($State))

## Returns the ui-marker of players.
func get_marker(p: State.Player) -> Node:
	var marker: Node = null
	if p == $State.Player.Cross:
		marker = cross_scene.instantiate()
	elif p == $State.Player.Circle:
		marker = circle_scene.instantiate()
	else:
		pass
	return marker
	
## Adds the marker of the play.
func update_view(pos: Vector2i) -> void:
	var p = $State.next($State.player)
	var marker = get_marker(p)
	marker.position = pos * cell_size + Vector2i(cell_size / 2, cell_size / 2)
	$Markers.add_child(marker)
	
		
	
	
